@@ -1,26 +1,26 @@
 test_that("plot censoring", {
   skip_on_cran()
 
-  dat <- xgxr::case1_pkpd %>%
-    dplyr::rename(DV=LIDV) %>%
-    dplyr::filter(CMT %in% 1:2) %>%
+  dat <- xgxr::case1_pkpd |>
+    dplyr::rename(DV=LIDV) |>
+    dplyr::filter(CMT %in% 1:2) |>
     dplyr::filter(TRTACT != "Placebo")
 
   doses <- unique(dat$DOSE)
   nid <- 10 # 7 ids per dose group
   dat2 <- do.call("rbind",
                   lapply(doses, function(x) {
-                    ids <- dat %>%
-                      dplyr::filter(DOSE == x) %>%
-                      dplyr::summarize(ids=unique(ID)) %>%
+                    ids <- dat |>
+                      dplyr::filter(DOSE == x) |>
+                      dplyr::summarize(ids=unique(ID)) |>
                       dplyr::pull()
                     ids <- ids[seq(1, nid)]
-                    dat %>%
+                    dat |>
                       dplyr::filter(ID %in% ids)
                   }))
 
   ## Use 2 compartment model
-  cmt2 <- function(){
+  cmt2 <- function() {
     ini({
       lka <- log(0.1) # log Ka
       lv <- log(10) # Log Vc
